loleaflet/src/control/Toolbar.js |    6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)

New commits:
commit a004938d3f54a718e17b523c78f4885b4fd0808e
Author:     Samuel Mehrbrodt <samuel.mehrbr...@cib.de>
AuthorDate: Wed Apr 17 09:04:03 2019 +0200
Commit:     Samuel Mehrbrodt <samuel.mehrbr...@cib.de>
CommitDate: Wed Apr 17 09:04:03 2019 +0200

    About dialog: Add link to website
    
    Can be modified by setting brandProductURL in branding.js
    
    Change-Id: I6181f4f0d7c0f7e6cd9ab447d95f451711bfd561

diff --git a/loleaflet/src/control/Toolbar.js b/loleaflet/src/control/Toolbar.js
index ba3cbb0ca..95b86b053 100644
--- a/loleaflet/src/control/Toolbar.js
+++ b/loleaflet/src/control/Toolbar.js
@@ -3,7 +3,7 @@
  * Toolbar handler
  */
 
 /* global $ window vex brandProductName _ */
 L.Map.include({
 
        // a mapping of uno commands to more readable toolbar items
@@ -256,9 +256,11 @@ L.Map.include({
                var content = $('#about-dialog').clone().css({display: 
'block'});
                // fill product-name and product-string
                var productName = (typeof brandProductName !== 'undefined') ? 
brandProductName : 'LibreOffice Online';
+               var productURL = (typeof brandProductURL !== 'undefined') ? 
brandProductURL : 'https://libreoffice.org';
+               var productNameWithURL = '<a href="' + productURL + '" 
target="_blank">' + productName + '</a>';
                content.find('#product-name').text(productName);
                var productString = _('This version of %productName is powered 
by');
-               
content.find('#product-string').text(productString.replace('%productName', 
productName));
+               
content.find('#product-string').html(productString.replace('%productName', 
productNameWithURL));
                var w;
@@ -3,7 +3,7 @@
  */
 
-/* global $ window vex brandProductName _ */
+/* global $ window vex brandProductName brandProductURL _ */
 L.Map.include({
 
                var iw = window.innerWidth;
                if (iw < 768) {
_______________________________________________
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits

Reply via email to